<?php

/**
 * Class Propoza_Propoza_Block_Quote_Request_Button
 */
class Propoza_Propoza_Block_Quote_Request_Button extends Mage_Core_Block_Template
{
    /**
     * @return bool
     */
    public function isDisabled()
    {
        return !Mage::getSingleton('checkout/session')->getQuote()->validateMinimumAmount();
    }

    /**
     * @return bool
     */
    public function isEnabled()
    {
        return $this->isPossibleOnepageCheckout() && !$this->isProposalQuote() && Mage::helper('propoza')->isConfigured(
        );
    }

    /**
     * @return mixed
     */
    public function isPossibleOnepageCheckout()
    {
        return $this->helper('checkout')->canOnepageCheckout();
    }

    /**
     * @return mixed
     */
    public function isProposalQuote()
    {
        return Mage::getModel('salesrule/rule')->isPropozaProposalRule(
            Mage::getSingleton('checkout/session')->getQuote()->getCouponCode()
        );
    }

    /**
     * @return string
     */
    public function getRequestQuoteFormHtmlUrl()
    {
        return Mage::getUrl(
            'propoza/ajax/requestQuoteFormHtml',
            array('_secure' => Mage::app()->getStore()->isCurrentlySecure())
        );
    }

    /**
     * @return string
     */
    public function getButton()
    {
        $config = null;
        if (!Mage::app()->getStore()->isCurrentlySecure()) {
            $config = array(
                'verify_peer' => false,
                'allow_self_signed' => true,
            );
        }
        $client = new Varien_Http_Client(Mage::helper('propoza')->getDashboardPropozaUrl() . '/api/MagentoQuotes/requestButton', $config);

        // @codingStandardsIgnoreLine
        $apiKey = explode(':', base64_decode(Mage::getStoreConfig('propoza/general/api_key')), 2);
        $client->setAuth($apiKey[0], $apiKey[1], Varien_Http_Client::AUTH_BASIC);
        $client->setMethod(Varien_Http_Client::GET);
        $client->setConfig(array('strictredirects' => true));
        $response = $client->request();
        return $response->getBody();
    }

    /**
     * @return string
     */
    public function getRequestQuoteFormSubmitUrl()
    {
        return Mage::getUrl(
            'propoza/ajax/requestQuoteFormSubmit',
            array('_secure' => Mage::app()->getStore()->isCurrentlySecure())
        );
    }

    /**
     * @param $type
     * @param $relativePath
     *
     * @return Propoza_Propoza_Block_Quote_Request_Button
     */
    public function addPropozaAssets($type, $relativePath)
    {
        if (strpos($relativePath, '/') !== 0) {
            $relativePath = sprintf('%s/', $relativePath);
        }
        $path = sprintf('%s%s', Mage::helper('propoza')->getDashboardPropozaUrl(), $relativePath);

        return $this->addExternalLink($type, $path);
    }

    /**
     * @param        $type
     * @param        $path
     * @param string $script
     *
     * @return $this
     */
    public function addExternalLink($type, $path, $script = '')
    {
        $head = $this->getLayout()->getBlock('head');

        switch ($type) {
            case'css':
                $tag
                    = sprintf('<link rel="stylesheet" type="text/css" href="%s"/>', $path);
                break;
            case 'javascript':
                $tag
                    = sprintf('<script type="text/javascript" src="%s"></script>', $path, $script);
                if (!empty($script)) {
                    $tag .= sprintf('<script>%s</script>', $script);
                }
                break;
        }

        $block = $this->getLayout()->createBlock('Mage_Core_Block_Text')->setText($tag);
        $head->append($block);

        return $this;
    }

    /**
     * @param $script
     * @param $cdn
     *
     * @return Propoza_Propoza_Block_Quote_Request_Button
     */
    public function addJQuery($script, $cdn)
    {
        $fullPath = Mage::getBaseDir() . '/js/' . $script;
        $ioFile = new Varien_Io_File();
        if (!$ioFile->fileExists($fullPath)) {
            return $this->addExternalLink('javascript', $cdn, '$j = jQuery.noConflict();');
        }

        return $this->getLayout()->getBlock('head')->addJs($script);
    }
}
