<?php

/**
 * Class Propoza_Propoza_Helper_Request
 */
class Propoza_Propoza_Helper_Request extends Mage_Core_Helper_Abstract
{
    /**
     * @param $quote
     *
     * @return array
     */
    public function prepareQuoteRequest($quote)
    {
        $toPropozaQuote = array();
        $toPropozaQuote['Quote'] = $this->prepareQuote($quote);
        $toPropozaQuote['Quote']['Requester'] = $this->prepareRequester(
            Mage::getSingleton('customer/session')->getCustomer()
        );
        $toPropozaQuote['Quote']['Product'] = $this->prepareProducts($quote);
        $toPropozaQuote['Quote']['shop_url'] = Mage::getBaseUrl(Mage_Core_Model_Store::URL_TYPE_WEB);

        return $toPropozaQuote;
    }

    /**
     * @param $quote
     *
     * @return array
     */
    protected function prepareQuote($quote)
    {
        $toPropozaQuote = array();
        $toPropozaQuote ['shop_quote_id'] = $quote->getId();
        $toPropozaQuote['cart_currency'] = Mage::app()->getStore()->getBaseCurrencyCode();
        $toPropozaQuote['include_default_store_tax'] = Mage::getStoreConfig(
            'tax/calculation/price_includes_tax', Mage::app()->getStore()->getId()
        );

        return $toPropozaQuote;
    }

    /**
     * @param $customer
     *
     * @return array
     */
    public function prepareRequester($customer)
    {
        $requester = array();
        $requester['firstname'] = $customer->getFirstname();
        $requester['middlename'] = $customer->getMiddlename();
        $requester['lastname'] = $customer->getLastname();
        $requester['email'] = $customer->getEmail();
        $requester['company'] = $this->getCurrentCustomerCompany($customer);

        return $requester;
    }

    /**
     * @param $customer
     *
     * @return null
     */
    public function getCurrentCustomerCompany($customer)
    {
        $company = null;
        if ($this->getCurrentCustomerBillingAddress($customer)) {
            $company = $this->getCurrentCustomerBillingAddress($customer)->getCompany();
        } else {
            if ($this->getCurrentCustomerShippingAddress($customer)) {
                $company = $this->getCurrentCustomerShippingAddress($customer)->getCompany();
            }
        }

        return $company;
    }

    /**
     * @param $customer
     *
     * @return bool|Mage_Core_Model_Abstract
     */
    public function getCurrentCustomerBillingAddress($customer)
    {
        $billingAddressId = $customer->getDefaultBilling();
        if ($billingAddressId) {
            return Mage::getModel('customer/address')->load($billingAddressId);
        } else {
            return false;
        }
    }

    /**
     * @param $customer
     *
     * @return bool|Mage_Core_Model_Abstract
     */
    public function getCurrentCustomerShippingAddress($customer)
    {
        $shippingAddressId = $customer->getDefaultShipping();
        if ($shippingAddressId) {
            return Mage::getModel('customer/address')->load($shippingAddressId);
        } else {
            return false;
        }
    }

    /**
     * @param $quote
     *
     * @return array
     */
    public function prepareProducts($quote)
    {
        $products = array();
        $count = 0;
        foreach ($quote->getAllVisibleItems() as $item) {
            $products[$count] = $this->prepareProduct($item);
            $products[$count]['Child'] = $this->prepareChildren($item);
            $count++;
        }

        return $products;
    }

    /**
     * @param $item
     *
     * @return array
     */
    public function prepareProduct($item)
    {
        $product = array();
        $product['name'] = $item->getName();
        $product['original_price'] = $item->getBaseOriginalPrice() !== null ? $item->getBaseOriginalPrice() : 0;
        $product['sku'] = $item->getSku();
        $product['quantity'] = $item->getQty();
        $product['ProductAttribute'] = $this->prepareProductAttributes($item);
        $product['external_url'] = $item->getProduct()->getProductUrl();

        return $product;
    }

    /**
     * @param $item
     *
     * @return array
     */
    public function prepareProductAttributes($item)
    {
        $productAttributes = array();
        $orderOptions = ($item->getProduct()->getTypeInstance(true)->getOrderOptions($item->getProduct()));
        $counter = 0;
        if (isset($orderOptions['options'])) {
            foreach ($orderOptions['options'] as $option) {
                $productAttributes[$counter]['name'] = $option['label'];
                $productAttributes[$counter]['value'] = $option['print_value'];
                $counter++;
            }
        }
        if (isset($orderOptions['attributes_info'])) {
            foreach ($orderOptions['attributes_info'] as $attribute) {
                $productAttributes[$counter]['name'] = $attribute['label'];
                $productAttributes[$counter]['value'] = $attribute['value'];
                $counter++;
            }
        }

        return $productAttributes;
    }

    /**
     * @param $parent
     *
     * @return array
     */
    public function prepareChildren($parent)
    {
        $children = array();
        if (count($parent->getChildren()) > 0) {
            foreach ($parent->getChildren() as $child) {
                if ($parent->getProductType() != Mage_Catalog_Model_Product_Type::TYPE_CONFIGURABLE) {
                    $children[] = $this->prepareProduct($child);
                }
            }
        }

        return $children;
    }


    /**
     * Get url to set quote as ordered request to
     *
     * @return string
     */
    public function getQuoteOrderedUrl()
    {
        return sprintf('%s/api/MagentoQuotes/edit.json', Mage::helper('propoza')->getDashboardPropozaUrl());
    }
}